<?php
/***************************************
  Meta - Employee office
****************************************/

defined( 'ABSPATH' ) or die( 'No script kiddies please!' );

class YSP_Employee_Office_Meta {

	public function __construct() {
        add_action( 'admin_init', array( $this, 'add' ) );
        add_action( 'save_post', array( $this, 'save' ) );
	}

	public function add() {
        add_meta_box(
            'employee_office_settings',
            __( 'Employee office', 'ysp-business' ),
            array( $this, 'meta_box' ),
            'employee',
            'side',
            'default',
            null
        );
	}

	public function meta_box( $post ) {

		wp_nonce_field( basename( __FILE__ ), '_employee-office-meta-nonce' );

        $post_meta = get_post_meta( $post->ID, '_employee_office', true );

        $args = array(
            'post_type' => 'office',
            'posts_per_page' => -1,
        );

        $query = new WP_Query($args);
        $offices = $query->get_posts();

        if (!empty($offices)) {
            ?><ul><?php

            foreach($offices as $office) {
                $post_id = $office->ID;
                $post_title = $office->post_title;
                $checked = ( is_array( $post_meta ) && in_array( $post_id, $post_meta ) ) ? ' checked' : '';
                ?>
                <li>
                    <input type="checkbox" name="employee_office[]" value="<?php echo $post_id; ?>"<?php echo $checked; ?>>
                    <label for="employee_office[]"><?php echo $post_title; ?></label>
                </li>
                <?php
            }

            ?></ul><?php
        }

        // Reset Postdata
        wp_reset_postdata();
	}

	public function save( $post_id ) {

		if ( ! isset( $_POST['_employee-office-meta-nonce'] ) || ! wp_verify_nonce( $_POST['_employee-office-meta-nonce'], basename( __FILE__ ) ) ) {
			return;
		}

		if ( ! current_user_can( 'edit_post', $post_id ) ) {
			return;
		}

		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
			return;
		}

		$fields = array(
            'employee_office'
        );

		foreach ( $fields as $field ) {
			if ( array_key_exists( $field, $_POST ) ) {
				update_post_meta(
					$post_id,
					'_' . $field,
					$_POST[ $field ]
				);
			} else {
				update_post_meta(
					$post_id,
					'_' . $field,
					''
				);
            }
		}

	}
}

new YSP_Employee_Office_Meta();