<?php
/***************************************
  Meta - Employee
****************************************/

defined( 'ABSPATH' ) or die( 'No script kiddies please!' );

class YSP_Employee_Meta {

	public function __construct() {
        add_action( 'admin_init', array( $this, 'add' ) );
        add_action( 'save_post', array( $this, 'save' ) );
	}

	public function add() {
        add_meta_box(
            'employee_information_settings',
            __( 'Employee information', 'ysp-business' ),
            array( $this, 'meta_box' ),
            'employee',
            'side',
            'default',
            null
        );
	}

	public function meta_box( $post ) {

		wp_nonce_field( basename( __FILE__ ), '_employee-meta-nonce' );
		?>
			<label for="employee_position"><strong><?php _e( 'Position', 'ysp-business' ); ?></strong></label><br/>
			<input name="employee_position" type="text" value="<?php echo get_post_meta( $post->ID, '_employee_position', true ); ?>">
			<br/><br/>
			<label for="employee_email_address"><strong><?php _e( 'Email address', 'ysp-business' ); ?></strong></label><br/>
			<input name="employee_email_address" type="text" value="<?php echo get_post_meta( $post->ID, '_employee_email_address', true ); ?>">
			<br/><br/>
			<label for="employee_phone_number"><strong><?php _e( 'Phone number', 'ysp-business' ); ?></strong></label><br/>
			<input name="employee_phone_number" type="text" value="<?php echo get_post_meta( $post->ID, '_employee_phone_number', true ); ?>">
			<br/><br/>
			<label for="employee_linkedin"><strong><?php _e( 'LinkedIn', 'ysp-business' ); ?></strong></label><br/>
			<input name="employee_linkedin" type="text" value="<?php echo get_post_meta( $post->ID, '_employee_linkedin', true ); ?>">
			<br/>
		<?php
	}

	public function save( $post_id ) {

		if ( ! isset( $_POST['_employee-meta-nonce'] ) || ! wp_verify_nonce( $_POST['_employee-meta-nonce'], basename( __FILE__ ) ) ) {
			return;
		}

		if ( ! current_user_can( 'edit_post', $post_id ) ) {
			return;
		}

		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
			return;
		}

		$fields = array(
            'employee_position',
            'employee_email_address',
            'employee_phone_number',
            'employee_linkedin'
        );

		foreach ( $fields as $field ) {
			if ( array_key_exists( $field, $_POST ) ) {
				update_post_meta(
					$post_id,
					'_' . $field,
					$_POST[ $field ]
				);
			}
		}
	}
}

new YSP_Employee_Meta();