<?php
/***************************************
  Meta - Office employees
****************************************/

defined( 'ABSPATH' ) or die( 'No script kiddies please!' );

class YSP_Office_Employees_Meta {

	public function __construct() {
        add_action( 'admin_init', array( $this, 'add' ) );
        add_action( 'save_post', array( $this, 'save' ) );
	}

	public function add() {
        add_meta_box(
            'office_employees_settings',
            __( 'Office employees', 'ysp-business' ),
            array( $this, 'meta_box' ),
            'office',
            'side',
            'default',
            null
        );
	}

	public function meta_box( $post ) {

		wp_nonce_field( basename( __FILE__ ), '_office-employees-meta-nonce' );
        
        $args = array(
            'post_type' => 'employee',
            'numberposts' => -1,
            'meta_query' => array(
                'relation' => 'AND',
                array(
                    'key'     => '_employee_office',
                    'compare' => 'EXISTS'
                ),
                array(
                    'key'     => '_employee_office',
                    'value'   => $post->ID,
                    'compare' => 'LIKE'
                ),
            ),
        );
        
        $employees = get_posts( $args );

        if( !empty( $employees ) ) {
            ?><ul><?php
            foreach ( $employees as $employee ) {
                ?>
                <li>
                    <p><a href="<?php echo get_edit_post_link( $employee->ID ); ?>"><?php echo $employee->post_title; ?></a></p>
                </li>
                <?php
            }
            ?></ul><?php
        } else {
            _e( 'Sorry, no employees here.', 'ysdp-business' );
        }

	}

	public function save( $post_id ) {

		if ( ! isset( $_POST['_office-employees-meta-nonce'] ) || ! wp_verify_nonce( $_POST['_office-employees-meta-nonce'], basename( __FILE__ ) ) ) {
			return;
		}

		if ( ! current_user_can( 'edit_post', $post_id ) ) {
			return;
		}

		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
			return;
		}
	}

}

new YSP_Office_Employees_Meta();