<?php
/***************************************
  Meta - Office
****************************************/

defined( 'ABSPATH' ) or die( 'No script kiddies please!' );

class YSP_Office_Office_Meta {

	public function __construct() {
        add_action( 'admin_init', array( $this, 'add' ) );
        add_action( 'save_post', array( $this, 'save' ) );
	}

	public function add() {
        add_meta_box(
            'office_information_settings',
            __( 'Office information', 'ysp-business' ),
            array( $this, 'meta_box' ),
            'office',
            'side',
            'default',
            null
        );
	}

	public function meta_box( $post ) {

		wp_nonce_field( basename( __FILE__ ), '_office-meta-nonce' );
		?>
			<label for="office_address"><strong><?php _e( 'Address', 'ysp-business' ); ?></strong></label><br/>
			<input name="office_address" type="text" value="<?php echo get_post_meta( $post->ID, '_office_address', true ); ?>">
			<br/><br/>
			<label for="office_email_address"><strong><?php _e( 'Email address', 'ysp-business' ); ?></strong></label><br/>
			<input name="office_email_address" type="text" value="<?php echo get_post_meta( $post->ID, '_office_email_address', true ); ?>">
			<br/><br/>
			<label for="office_phone_number"><strong><?php _e( 'Phone number', 'ysp-business' ); ?></strong></label><br/>
			<input name="office_phone_number" type="text" value="<?php echo get_post_meta( $post->ID, '_office_phone_number', true ); ?>">
			<br/><br/>
			<label for="office_linkedin"><strong><?php _e( 'LinkedIn', 'ysp-business' ); ?></strong></label><br/>
			<input name="office_linkedin" type="text" value="<?php echo get_post_meta( $post->ID, '_office_linkedin', true ); ?>">
			<br/>
		<?php
	}

	public function save( $post_id ) {

		if ( ! isset( $_POST['_office-meta-nonce'] ) || ! wp_verify_nonce( $_POST['_office-meta-nonce'], basename( __FILE__ ) ) ) {
			return;
		}

		if ( ! current_user_can( 'edit_post', $post_id ) ) {
			return;
		}

		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
			return;
		}

		$fields = array(
            'office_address',
            'office_email_address',
            'office_phone_number',
            'office_linkedin',
        );

		foreach ( $fields as $field ) {
			if ( array_key_exists( $field, $_POST ) ) {
				update_post_meta(
					$post_id,
					'_' . $field,
					$_POST[ $field ]
				);
			}
		}
	}

}

new YSP_Office_Office_Meta();