<?php

/**
 * Business Plugin Helpers
 * Helpers: get_image_sizes, get_term_list, generate_css_class, build_link, generate_post_list
 */

class YSP_Business_Helpers {

	public static function get_image_sizes() {
		global $_wp_additional_image_sizes;

		$sizes  = array();
		$output = array();

		$get_sizes = get_intermediate_image_sizes();

		array_push( $get_sizes, 'full' );

		$get_sizes = array_combine( $get_sizes, $get_sizes );

		foreach ( $get_sizes as $_size ) {
			if ( in_array( $_size, array( 'full', 'thumbnail', 'medium', 'medium_large', 'large' ) ) ) {
				$sizes[ $_size ]['width']  = get_option( "{$_size}_size_w" );
				$sizes[ $_size ]['height'] = get_option( "{$_size}_size_h" );
				$sizes[ $_size ]['crop']   = (bool) get_option( "{$_size}_crop" );
			} elseif ( isset( $_wp_additional_image_sizes[ $_size ] ) ) {
				$sizes[ $_size ] = array(
					'width'  => $_wp_additional_image_sizes[ $_size ]['width'],
					'height' => $_wp_additional_image_sizes[ $_size ]['height'],
					'crop'   => $_wp_additional_image_sizes[ $_size ]['crop'],
				);
			}
		}

		foreach ( $sizes as $image_size => $image_size_data ) {
			$crop = $height = $width = '';

			$img_size_name = str_replace( '_', ' ', ucwords( $image_size ) );

			// If image size is not full
			if ( $image_size_data['height'] != false && $image_size_data['width'] != false ) {
				$height = $image_size_data['height'] === '0' ? 'auto' : $image_size_data['height'];
				$width  = $image_size_data['width'] === '0' ? 'auto' : $image_size_data['width'];

				$img_size_name .= ' (' . $width . ' x ' . $height . ')';
			}

			// Croop info
			//
			// if(is_array($image_size_data['crop'])){
			// $crop = 'true '.$image_size_data['crop'][0].'-'.$image_size_data['crop'][0];
			// }else{
			// $crop = $image_size_data['crop'] ? 'true auto' : 'false';
			// }
			$output[ $img_size_name ] = $image_size;
		}

		return $output;
	}

	public static function get_term_list( $taxonomy, $default = true ) {

		$list = $default ? array( '---' => false ) : array();

		$tax = $taxonomy ? $taxonomy : false;

		if ( ! $tax ) {
			return;
		}

		$terms = get_terms(
			array(
				'taxonomy'   => $tax,
				'hide_empty' => true,
			)
		);

		// Check if taxonomy is valid
		if ( is_wp_error( $terms ) ) {
			return array();
		} else {
			foreach ( $terms as $key => $value ) {
				$list[ $value->name ] = $value->term_id;
			}
		}

		return $list;
	}

	 /**
	  * Generate a string based on array values.
	  */
	public static function generate_css_class( $class = array(), $flush = false ) {
		$output = '';
		$space  = $flush ? '' : ' ';

		if ( empty( $class ) ) {
			return false;
		}

		// Check is we get an array
		if ( is_array( $class ) ) {
			$isFirst = 0;

			foreach ( $class as $css_class ) {
				++$isFirst;

				// if we have multiple values flush only the first space
				if ( 1 === $isFirst && $flush ) {
					$space = '';
				} else {
					$space = ' ';
				}

				// Check if we have a valid value and field is not empty
				if ( ! empty( $css_class ) ) {
					$output .= $space . $css_class;
				}
			}
		} else {
			// Check if we have a valid value and field is not empty
			if ( ! empty( $class ) ) {
				$output = $space . $class;
			}
		}

		return $output;
	}

	private static function parse_multi_attribute( $value, $default = array() ) {
		$result       = $default;
		$params_pairs = explode( '|', $value );
		if ( ! empty( $params_pairs ) ) {
			foreach ( $params_pairs as $pair ) {
				$param = preg_split( '/\:/', $pair );
				if ( ! empty( $param[0] ) && isset( $param[1] ) ) {
					$result[ $param[0] ] = rawurldecode( $param[1] );
				}
			}
		}

		return $result;
	}

	public static function build_link( $value ) {
		return self::parse_multi_attribute(
			$value,
			array(
				'url'    => '',
				'title'  => '',
				'target' => '',
				'rel'    => '',
			)
		);
	}

	public static function generate_post_list( $post_type, $array_invert = false, $add_empty = false ) {
		$p_type = $post_type ? $post_type : false;

		$list = array();

		if ( ! $p_type ) {
			return array( '' => '' ); // empty
		}

		$args = array(
			'post_type'      => $p_type,
			'posts_per_page' => -1,
			'orderby'        => 'title',
			'order'          => 'ASC',
		);

		$post_list = get_posts( $args );

		if ( $post_list ) {
			foreach ( $post_list as $post ) {
				setup_postdata( $post );
				$title = get_the_title( $post->ID );

				if ( $array_invert ) {
					if ( $add_empty ) {
						$list[0] = '---';
					}
					$list[ $post->ID ] = $title;
				} else {
					if ( $add_empty ) {
						$list['---'] = 0;
					}
					$list[ $title ] = $post->ID;
				}
			}
			wp_reset_postdata();
		}

		return $list;
	}

    public static function get_icon( $icon = '' ) {

        $output = '';
        if ( empty( $icon ) ) {
            return;
        }

        switch( $icon ) {
            case 'award-simple':
                $output = '<svg aria-hidden="true" focusable="false" data-prefix="fal" data-icon="award-simple" class="svg-inline--fa fa-award-simple fa-w-14" role="img" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 384 512"><path d="M192 104C143.4 104 104 143.3 104 192c0 48.58 39.39 88 87.1 88S279.1 240.6 279.1 192C279.1 143.3 240.6 104 192 104zM192 248C161.1 248 136 222.9 136 192c0-30.88 25.12-56 55.1-56S247.1 161.1 247.1 192C247.1 222.9 222.9 248 192 248zM384 192c0-16.5-17.27-30.52-21.34-45.73c-4.207-15.75 3.608-36.5-4.369-50.29c-8.086-13.98-30.03-17.52-41.37-28.87c-11.35-11.35-14.88-33.29-28.87-41.39c-13.76-7.963-34.62-.1888-50.29-4.378C222.5 17.27 208.5 0 192 0C175.5 0 161.5 17.27 146.3 21.34C130.5 25.54 109.7 17.74 95.98 25.71C81.1 33.79 78.46 55.74 67.11 67.08C55.77 78.43 33.82 81.96 25.73 95.95C17.74 109.7 25.55 130.5 21.35 146.2C17.27 161.5 0 175.5 0 192c0 16.5 17.27 30.52 21.34 45.73c4.207 15.75-3.612 36.5 4.365 50.29C33.8 302 55.74 305.5 67.08 316.9c11.35 11.35 14.88 33.29 28.86 41.39c13.74 7.951 34.62 .1803 50.29 4.38C161.5 366.7 175.5 384 192 384c16.5 0 30.52-17.27 45.74-21.34c15.72-4.207 36.5 3.603 50.29-4.368c13.98-8.088 17.52-30.03 28.87-41.38c11.35-11.35 33.29-14.88 41.39-28.86c7.981-13.79 .1698-34.54 4.377-50.29C366.7 222.5 384 208.5 384 192zM331.7 229.5c-4.404 16.49-1.34 32.1-1.695 42.27c-7.858 4.969-23.64 10.38-35.78 22.52c-12.03 12.03-17.59 27.99-22.5 35.75c-9.195 .4141-25.54-2.775-42.28 1.703c-16.71 4.467-29.4 15.76-37.48 19.79c-8.029-4.002-20.8-15.34-37.48-19.79c-16.71-4.477-33.04-1.301-42.29-1.717C107.3 322.2 101.8 306.4 89.71 294.3C77.6 282.1 61.86 276.8 53.94 271.7C53.59 262.5 56.7 246.1 52.25 229.5c-4.465-16.71-15.77-29.39-19.8-37.48c3.996-8.025 15.33-20.77 19.8-37.5c4.434-16.6 1.33-32.88 1.697-42.27c7.854-4.971 23.64-10.37 35.78-22.52C101.8 77.68 107.3 61.72 112.2 53.95c9.194-.377 25.64 2.738 42.28-1.701c16.74-4.475 29.33-15.74 37.48-19.79c8.027 3.992 20.77 15.33 37.49 19.8c16.74 4.471 33.01 1.295 42.28 1.711c4.84 7.65 10.45 23.71 22.51 35.76c12.03 12.04 28 17.61 35.77 22.52c.3555 9.273-2.752 25.64 1.693 42.28c4.469 16.71 15.77 29.38 19.79 37.47C347.6 200 336.2 212.8 331.7 229.5zM303.7 399.7c-1.813-8.656-10.16-14.23-18.94-12.39c-8.625 1.797-14.19 10.27-12.38 18.92l17.47 73.84l-90.66-45.33c-4.5-2.25-9.813-2.25-14.31 0l-88.88 46.72l15.69-75.23c1.813-8.656-3.75-17.12-12.38-18.92c-8.688-1.844-17.16 3.734-18.94 12.39l-15.69 75.25c-2.438 11.64 1.938 23.38 11.34 30.62c9.438 7.234 21.84 8.438 32.5 3.125L192 466.1l83.5 41.75C279.9 510.9 284.6 512 289.3 512c6.625 0 13.16-2.172 18.69-6.406c9.406-7.25 13.78-18.98 11.34-30.64L303.7 399.7z"/></svg>';
                break;
            case 'envelope':
                $output = '<svg aria-hidden="true" focusable="false" data-prefix="fal" data-icon="envelope" class="svg-inline--fa fa-envelope fa-w-16" role="img" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 512 512"><path fill="currentColor" d="M464 64H48C21.5 64 0 85.5 0 112v288c0 26.5 21.5 48 48 48h416c26.5 0 48-21.5 48-48V112c0-26.5-21.5-48-48-48zM48 96h416c8.8 0 16 7.2 16 16v41.4c-21.9 18.5-53.2 44-150.6 121.3-16.9 13.4-50.2 45.7-73.4 45.3-23.2.4-56.6-31.9-73.4-45.3C85.2 197.4 53.9 171.9 32 153.4V112c0-8.8 7.2-16 16-16zm416 320H48c-8.8 0-16-7.2-16-16V195c22.8 18.7 58.8 47.6 130.7 104.7 20.5 16.4 56.7 52.5 93.3 52.3 36.4.3 72.3-35.5 93.3-52.3 71.9-57.1 107.9-86 130.7-104.7v205c0 8.8-7.2 16-16 16z"></path></svg>';
                break;
            case 'phone':
                $output = '<svg aria-hidden="true" focusable="false" data-prefix="fal" data-icon="phone" class="svg-inline--fa fa-phone fa-w-16" role="img" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 512 512"><path fill="currentColor" d="M487.8 24.1L387 .8c-14.7-3.4-29.8 4.2-35.8 18.1l-46.5 108.5c-5.5 12.7-1.8 27.7 8.9 36.5l53.9 44.1c-34 69.2-90.3 125.6-159.6 159.6l-44.1-53.9c-8.8-10.7-23.8-14.4-36.5-8.9L18.9 351.3C5 357.3-2.6 372.3.8 387L24 487.7C27.3 502 39.9 512 54.5 512 306.7 512 512 307.8 512 54.5c0-14.6-10-27.2-24.2-30.4zM55.1 480l-23-99.6 107.4-46 59.5 72.8c103.6-48.6 159.7-104.9 208.1-208.1l-72.8-59.5 46-107.4 99.6 23C479.7 289.7 289.6 479.7 55.1 480z"></path></svg>';
                break;
            case 'tags':
                $output = '<svg aria-hidden="true" focusable="false" data-prefix="fal" data-icon="tags" class="svg-inline--fa fa-tags fa-w-20" role="img" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 640 512"><path fill="currentColor" d="M625.941 293.823L421.823 497.941c-18.746 18.746-49.138 18.745-67.882 0l-1.775-1.775 22.627-22.627 1.775 1.775c6.253 6.253 16.384 6.243 22.627 0l204.118-204.118c6.238-6.239 6.238-16.389 0-22.627L391.431 36.686A15.895 15.895 0 0 0 380.117 32h-19.549l-32-32h51.549a48 48 0 0 1 33.941 14.059L625.94 225.941c18.746 18.745 18.746 49.137.001 67.882zM252.118 32H48c-8.822 0-16 7.178-16 16v204.118c0 4.274 1.664 8.292 4.686 11.314l211.882 211.882c6.253 6.253 16.384 6.243 22.627 0l204.118-204.118c6.238-6.239 6.238-16.389 0-22.627L263.431 36.686A15.895 15.895 0 0 0 252.118 32m0-32a48 48 0 0 1 33.941 14.059l211.882 211.882c18.745 18.745 18.745 49.137 0 67.882L293.823 497.941c-18.746 18.746-49.138 18.745-67.882 0L14.059 286.059A48 48 0 0 1 0 252.118V48C0 21.49 21.49 0 48 0h204.118zM144 124c-11.028 0-20 8.972-20 20s8.972 20 20 20 20-8.972 20-20-8.972-20-20-20m0-28c26.51 0 48 21.49 48 48s-21.49 48-48 48-48-21.49-48-48 21.49-48 48-48z"></path></svg>';
                break;
            case 'building':
                $output = '<svg aria-hidden="true" focusable="false" data-prefix="fal" data-icon="building" class="svg-inline--fa fa-building fa-w-14" role="img" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 448 512"><path fill="currentColor" d="M192 107v40c0 6.627-5.373 12-12 12h-40c-6.627 0-12-5.373-12-12v-40c0-6.627 5.373-12 12-12h40c6.627 0 12 5.373 12 12zm116-12h-40c-6.627 0-12 5.373-12 12v40c0 6.627 5.373 12 12 12h40c6.627 0 12-5.373 12-12v-40c0-6.627-5.373-12-12-12zm-128 96h-40c-6.627 0-12 5.373-12 12v40c0 6.627 5.373 12 12 12h40c6.627 0 12-5.373 12-12v-40c0-6.627-5.373-12-12-12zm128 0h-40c-6.627 0-12 5.373-12 12v40c0 6.627 5.373 12 12 12h40c6.627 0 12-5.373 12-12v-40c0-6.627-5.373-12-12-12zm-128 96h-40c-6.627 0-12 5.373-12 12v40c0 6.627 5.373 12 12 12h40c6.627 0 12-5.373 12-12v-40c0-6.627-5.373-12-12-12zm128 0h-40c-6.627 0-12 5.373-12 12v40c0 6.627 5.373 12 12 12h40c6.627 0 12-5.373 12-12v-40c0-6.627-5.373-12-12-12zm140 205v20H0v-20c0-6.627 5.373-12 12-12h20V24C32 10.745 42.745 0 56 0h336c13.255 0 24 10.745 24 24v456h20c6.627 0 12 5.373 12 12zm-64-12V32H64v448h128v-85c0-6.627 5.373-12 12-12h40c6.627 0 12 5.373 12 12v85h128z"></path></svg>';
                break;
            case 'map-marker':
                $output = '<svg aria-hidden="true" focusable="false" data-prefix="fal" data-icon="map-marker" class="svg-inline--fa fa-map-marker fa-w-12" role="img" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 384 512"><path fill="currentColor" d="M192 0C85.961 0 0 85.961 0 192c0 77.413 26.97 99.031 172.268 309.67 9.534 13.772 29.929 13.774 39.465 0C357.03 291.031 384 269.413 384 192 384 85.961 298.039 0 192 0zm0 473.931C52.705 272.488 32 256.494 32 192c0-42.738 16.643-82.917 46.863-113.137S149.262 32 192 32s82.917 16.643 113.137 46.863S352 149.262 352 192c0 64.49-20.692 80.47-160 281.931z"></path></svg>';
                break;
            case 'linkedin':
                $output = '<svg aria-hidden="true" focusable="false" data-prefix="fab" data-icon="linkedin" class="svg-inline--fa fa-linkedin fa-w-14" role="img" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 448 512"><path fill="currentColor" d="M416 32H31.9C14.3 32 0 46.5 0 64.3v383.4C0 465.5 14.3 480 31.9 480H416c17.6 0 32-14.5 32-32.3V64.3c0-17.8-14.4-32.3-32-32.3zM135.4 416H69V202.2h66.5V416zm-33.2-243c-21.3 0-38.5-17.3-38.5-38.5S80.9 96 102.2 96c21.2 0 38.5 17.3 38.5 38.5 0 21.3-17.2 38.5-38.5 38.5zm282.1 243h-66.4V312c0-24.8-.5-56.7-34.5-56.7-34.6 0-39.9 27-39.9 54.9V416h-66.4V202.2h63.7v29.2h.9c8.9-16.8 30.6-34.5 62.9-34.5 67.2 0 79.7 44.3 79.7 101.9V416z"></path></svg>';
                break;
        }

        return $output;

    }

    public static function get_label( $setting = '', $custom = '', $default = '' ) {

        $label = '';

        $label = ( ! $setting ) ? $default : '';
        if ( ! empty( $setting ) && 'custom' == $setting ) {
            $label = str_replace( array( '``', '`{`', '`}`' ), array( '"', '[', ']' ), $custom );
            $label = do_shortcode( $label );
        }

        return $label;

    }


}