<?php

/**
 * Business Templates
 */

class YSP_Business_Templates {

	function __construct() {
        add_filter( 'single_template', array( $this, 'business_override_single_template' ) );
    }

    function business_override_single_template( $single_template ) {
        global $post;

        $template = YSP_BUSINESS_DIR .'public/partials/templates/single-'. $post->post_type .'.php';

        if ( file_exists( $template ) ) {
            $single_template = $template;
        }

        return $single_template;
    }

    static function render_single_template_content($post_id) {
        ?>
        <article id="post-<?php echo $post_id; ?>" <?php post_class( 'employee-article' ); ?>>

            <header class="entry-header">
                <div class="entry-header__first">
                    <div class="employee-thumbnail">
                        <?php echo get_the_post_thumbnail( $post_id, 'large', array( 'class' => 'employee-thumbnail__image' ) ); ?>
                    </div>
                </div>
                <div class="entry-header__second">
                    <div class="entry-header__second-top">
                        <h1 class="employee-name"><?php echo get_the_title($post_id); ?></h1>
                    </div>
                    <div class="entry-header__second-bottom">
                        <?php $position = get_post_meta( $post_id, '_employee_position', true ); ?>
                        <?php if ( ! empty( $position ) ) : ?>
                            <div class="employee-info__position">
                                <span class="employee-icon"><?php echo YSP_Business_Helpers::get_icon( 'award-simple' ); ?></span>
                                <?php echo $position; ?>
                            </div>
                        <?php endif; ?>
                        <?php $email = get_post_meta( $post_id, '_employee_email_address', true ); ?>
                        <?php if ( ! empty( $email ) ) : ?>
                            <div class="employee-info__email">
                                <span class="employee-icon"><?php echo YSP_Business_Helpers::get_icon( 'envelope' ); ?></span>
                                <?php echo $email; ?>
                            </div>
                        <?php endif; ?>
                        <?php $phone = get_post_meta( $post_id, '_employee_phone_number', true ); ?>
                        <?php if ( ! empty( $phone ) ) : ?>
                            <div class="employee-info__phone">
                                <span class="employee-icon"><?php echo YSP_Business_Helpers::get_icon( 'phone' ); ?></span>
                                <?php echo $phone; ?>
                            </div>
                        <?php endif; ?>
                        <?php $linkedin = get_post_meta( $post_id, '_employee_linkedin', true ); ?>
                        <?php if ( ! empty( $linkedin ) ) : ?>
                            <div class="employee-info__linkedin">
                                <span class="employee-icon"><?php echo YSP_Business_Helpers::get_icon( 'linkedin' ); ?></span>
                                <?php echo sprintf(
                                    '<a href="%s" target="_blank">%s</a>',
                                    $linkedin,
                                    __( 'LinkedIn', 'ysp-business' ),
                                ); ?>
                            </div>
                        <?php endif; ?>
                        <?php
                            $cats = get_the_terms( $post_id, 'employee_category' );
                            if ( ! empty( $cats ) ) {
                                $i = 0;
                                $numCats = $cats ? count( $cats ) : '';
                                ?>
                                <div class="employee-info__categories">
                                    <span class="employee-icon"><?php echo YSP_Business_Helpers::get_icon( 'tags' ); ?></span>
                                    <?php
                                        foreach ( $cats as $cat ) {
                                            echo $cat->name;
                                            if ( ++$i !== $numCats ) {
                                                echo ' | ';
                                            }
                                        }
                                    ?>
                                </div>
                            <?php
                            }
                        ?>
                        <?php
                            $offices = get_post_meta( $post_id, '_employee_office', true );
                            if ( ! empty( $offices ) ) {
                                $i = 0;
                                $numOffices = $offices ? count( $offices ) : '';
                                ?>
                                <div class="employee-info__offices">
                                    <span class="employee-icon"><?php echo YSP_Business_Helpers::get_icon( 'building' ); ?></span>
                                    <?php
                                        foreach ( $offices as $office ) {
                                            if ( !empty( get_post( $office ) ) ) {
                                                echo get_post( $office )->post_title;
                                                if ( ++$i !== $numOffices ) {
                                                    echo ' | ';
                                                }
                                            }
                                        }
                                    ?>
                                </div>
                            <?php
                            }
                        ?>
                    </div>
                </div>
            </header>

            <div class="entry-content">
                <?php echo do_shortcode(wpautop(get_the_content('', '', $post_id))); ?>
            </div>
            
            <footer class="entry-footer"></footer>

        </article>
        <?php
    }

}
new YSP_Business_Templates();