<?php
/**
 * VC Shortcode - Employee List
 *
 * @since 1.0
 */

class YSP_Business_Employee_List_Shortcode {

	public function __construct() {
		add_shortcode( 'ysp_business_employee_list', array( $this, 'ysp_business_employee_list' ) );
	}

	public function ysp_business_employee_list( $atts ) {
		$options = shortcode_atts(
			array(
				'per_line'          =>  '2',
				'category_id'       =>  false,
				'office_id'         =>  false,
				'img_size'          =>  'full',
				'link_single'       =>  false,
				'hide_position'     =>  false,
				'label_position'    =>  false,
				'hide_email'        =>  false,
				'label_email'       =>  false,
				'hide_phone'        =>  false,
				'label_phone'       =>  false,
		        'hide_linkedin'     =>  false,
		        'label_linkedin'    =>  false,
				'orderby'           =>  'menu_order',
				'order'             =>  'ASC',
				'class'             =>  '',
			),
			$atts,
			'ysp_business_employee_list'
		);

		$filter_query = array(
			'post_type'      => 'employee',
			'posts_per_page' => -1,
			'orderby'        => $options['orderby'],
			'order'          => $options['order'],
		);

		if ( $options['category_id'] ) {
			$filter_query['tax_query'] = array(
				array(
					'taxonomy' => 'employee_category',
					'field'    => 'term_id',
					'terms'    => array( $options['category_id'] ),
				),
			);
		}

		if ( $options['office_id'] ) {
			$filter_query['meta_query'] = array(
                'meta_query' => array(
                    'relation' => 'AND',
                    array(
                        'key'     => '_employee_office',
                        'compare' => 'EXISTS'
                    ),
                    array(
                        'key'     => '_employee_office',
                        'value'   => $options['office_id'],
                        'compare' => 'LIKE'
                    ),
                )
            );
		}

        // Enqueue Style
		wp_enqueue_style( 'ysp-business' );
        
        // Enqueue Script
        wp_enqueue_script( 'ysp-business' );

		$output = $employee_list = '';

		// Add custom class
		$customCss = YSP_Business_Helpers::generate_css_class(
			array(
				'c-employee-list',
				$options['class'],
				'c-employee-show-' . $options['per_line'],
			),
			true
		);

		$the_query = new WP_query( $filter_query );

		if ( $the_query->have_posts() ) {

			$employee = new Business_Employee_Template();

			while ( $the_query->have_posts() ) {
				$the_query->the_post();

				$args = array(
					'post_id'           =>  get_the_ID(),
					'img_size'          =>  $options['img_size'],
					'link_single'       =>  $options['link_single'],
                    'hide_position'     =>  $options['hide_position'],
                    'label_position'    =>  $options['label_position'],
                    'hide_email'        =>  $options['hide_email'],
                    'label_email'       =>  $options['label_email'],
                    'hide_phone'        =>  $options['hide_phone'],
                    'label_phone'       =>  $options['label_phone'],
                    'hide_linkedin'     =>  $options['hide_linkedin'],
                    'label_linkedin'    =>  $options['label_linkedin'],
				);

				$employee->setArgs( $args );

				$employee_list .= $employee->render();

			}
			wp_reset_postdata();
		}

		// Wrap all output.
		$output = '<div class="' . $customCss . '">' . $employee_list . '</div>';

		return $output;
	}

}
new YSP_Business_Employee_List_Shortcode();