<?php
/**
 * VC Integration - Employee Slider
 *
 * @since 1.0
 */

class YSP_Business_Employee_Slider_Shortcode {

	public function __construct() {
		add_shortcode( 'ysp_business_employee_slider', array( $this, 'ysp_business_employee_slider' ) );
	}

	public function ysp_business_employee_slider( $atts ) {
		$options = shortcode_atts(
			array(
				'slides'            =>  '4',
				'category_id'       =>  false,
				'office_id'         =>  false,
				'img_size'          =>  'full',
				'link_single'       =>  false,
				'slider_autoplay'   =>  'false',
				'slider_speed'      =>  '5000',
				'slider_loop'       =>  'false',
				'slider_space'      =>  '16',
				'slider_pagination' =>  false,
				'slider_navigation' =>  false,
				'hide_position'     =>  false,
				'label_position'    =>  false,
				'hide_email'        =>  false,
				'label_email'       =>  false,
				'hide_phone'        =>  false,
				'label_phone'       =>  false,
		        'hide_linkedin'     =>  false,
		        'label_linkedin'    =>  false,
				'orderby'           =>  'menu_order',
				'order'             =>  'ASC',
				'class'             =>  '',
                'slider_pagination_color'   =>  false,
                'slider_navigation_color'   =>  false,
			),
			$atts,
			'ysp_business_employee_slider'
		);

		$filter_query = array(
			'post_type'      => 'employee',
			'posts_per_page' => -1,
			'orderby'        => $options['orderby'],
			'order'          => $options['order'],
		);

		if ( $options['category_id'] ) {
			$filter_query['tax_query'] = array(
				array(
					'taxonomy' => 'employee_category',
					'field'    => 'term_id',
					'terms'    => array( $options['category_id'] ),
				),
			);
		}

		if ( $options['office_id'] ) {
			$filter_query['meta_query'] = array(
                'meta_query' => array(
                    'relation' => 'AND',
                    array(
                        'key'     => '_employee_office',
                        'compare' => 'EXISTS'
                    ),
                    array(
                        'key'     => '_employee_office',
                        'value'   => $options['office_id'],
                        'compare' => 'LIKE'
                    ),
                )
            );
		}

        // Enqueue Style
        wp_enqueue_style( 'ysp-business' );

		// Enqueue Swiper Style
        wp_enqueue_style( 'swiper_style_core' );

		// Enqueue Swiper Script
		wp_enqueue_script( 'ysp-business-slider' );

		$output = '';

		// Add custom class
		$customCss = YSP_Business_Helpers::generate_css_class(
			array(
				'c-employee-slider',
				$options['class'],
            ), true
		);

		$the_query = new WP_query( $filter_query );

		if ( $the_query->have_posts() ) {

			$employee = new Business_Employee_Template();

			while ( $the_query->have_posts() ) {
				$the_query->the_post();

				$args = array(
					'post_id'           =>  get_the_ID(),
					'img_size'          =>  $options['img_size'],
					'link_single'       =>  $options['link_single'],
                    'hide_position'     =>  $options['hide_position'],
                    'label_position'    =>  $options['label_position'],
                    'hide_email'        =>  $options['hide_email'],
                    'label_email'       =>  $options['label_email'],
                    'hide_phone'        =>  $options['hide_phone'],
                    'label_phone'       =>  $options['label_phone'],
                    'hide_linkedin'     =>  $options['hide_linkedin'],
                    'label_linkedin'    =>  $options['label_linkedin'],
				);

				$employee->setArgs( $args );

				$employee_list = $employee->render();

				$output .= sprintf(
					'<div class="swiper-slide">
                        <div class="c-employee-slide">
					        <div class="c-employee-slide__container">%s</div>
					    </div>
                    </div>',
					$employee_list
				);
			}
			wp_reset_postdata();
		} else {
			$output = __( 'Sorry, no posts were found', 'ysp-business' );
		}

        $pagination_color = ($options['slider_pagination_color']) ? 'style="color:'. $options['slider_pagination_color'] .';"' : '';
        $navigation_color = ($options['slider_navigation_color']) ? 'style="color:'. $options['slider_navigation_color'] .';"' : '';

        $pagination = ($options['slider_pagination']) ? '<div class="swiper-pagination"'. $pagination_color .'></div>' : '';
        $navigation = ($options['slider_navigation']) ? '<div class="swiper-button-prev"'. $navigation_color .'></div><div class="swiper-button-next"'. $navigation_color .'></div>' : '';

		// Wrap all output.
		$result = sprintf(
			'<div class="%s">
				<div class="swiper">
					<div class="swiper-container" data-slides="%s" data-autoplay="%s" data-speed="%s" data-loop="%s" data-space="%s">
                        <div class="swiper-wrapper">%s</div>
                        %s
                        %s
				    </div>
			    </div>
			</div>',
			$customCss,
			$options['slides'],
			$options['slider_autoplay'],
			$options['slider_speed'],
			$options['slider_loop'],
			$options['slider_space'],
			$output,
            $pagination,
            $navigation
		);

		return $result;
	}
}
new YSP_Business_Employee_Slider_Shortcode();