<?php
/***************************************
  Template - Employee
****************************************/

class Business_Employee_Template {

	private $settings = array(
		'post_id'          => null,
		'img_size'         => 'thumbnail',
		'link_single'      => false,
		'hide_position'    => false,
		'label_position'   => false,
		'hide_email'       => false,
		'label_email'      => false,
		'hide_phone'       => false,
		'label_phone'      => false,
		'hide_linkedin'    => false,
		'label_linkedin'   => false,
	);

	public function setArgs( $args ) {

		if ( ! empty( $args ) ) {
			foreach ( $args as $key => $value ) {
				$this->settings[ $key ] = $value;
			}
		}

	}

	public function render() {

		if ( ! isset( $this->settings['post_id'] ) ) {
			return '';
		}

		/**
		 * Setup initial options
		 */
		$post_id  = $this->settings['post_id'];
		$settings = $this->settings;

        // Declare Variables
        $label_position = $label_email = $label_phone = $label_linkedin = '';
        $position = $email = $phone = $linkedin = '';

        $label_position = YSP_Business_Helpers::get_label(
            $settings['hide_position'],
            $settings['label_position'],
            sprintf( '<span class="c-employee__label">%s</span>', __( 'Position:', 'ysp-business' ) ),
        );

        $label_email = YSP_Business_Helpers::get_label(
            $settings['hide_email'],
            $settings['label_email'],
            sprintf( '<span class="c-employee__label">%s</span>', __( 'Email:', 'ysp-business' ) ),
        );

        $label_phone = YSP_Business_Helpers::get_label(
            $settings['hide_phone'],
            $settings['label_phone'],
            sprintf( '<span class="c-employee__label">%s</span>', __( 'Phone:', 'ysp-business' ) ),
        );

        $label_linkedin = YSP_Business_Helpers::get_label(
            $settings['hide_linkedin'],
            $settings['label_linkedin'],
            YSP_Business_Helpers::get_icon('linkedin'),
        );

		/**
		 * Setup employee data
		 */
		$employee = $this->get_post_type_data( $post_id, $settings['img_size'], 'c-employee__image' );

		/**
		 * Setup template elements content
		 */
		$title = get_the_title( $post_id );

		if ($settings['link_single'] == 'true') {
            $link_start = '<a href="' . get_the_permalink( $post_id ) . '">';
            $link_end   = '</a>';
        } elseif ($settings['link_single'] == 'popup') {
            $link_start = '<a class="YSPBusinessTogglePopup" data-popup='.$post_id.' href="#">';
            $link_end   = '</a>';
        } else {
            $link_start = '';
        }

		$image = $employee['image'] ? $link_start . $employee['image'] . $link_end : '';

		if ( $employee['position'] ) {
		    $position = sprintf(
                '<div class="c-employee__position">%s%s</div>',
                $label_position . ' ',
                $employee['position']
            );
        }

		if ( $employee['email'] ) {
		    $email    = sprintf(
                '<div class="c-employee__email">%s<a class="c-employee__link" href="mailto:%s">%s</a></div>',
                $label_email . ' ',
                $employee['email'],
                $employee['email']
            );
        }

		if ( $employee['phone'] ) {
		    $phone    = sprintf(
                '<div class="c-employee__phone">%s<a class="c-employee__link" href="tel:%s">%s</a></div>',
                $label_phone . ' ',
                $employee['phone'],
                $employee['phone']
            );
        }

		if ( $employee['linkedin'] ) {
            $linkedin = sprintf(
                '<div class="c-employee__icon c-employee__linkedin"><a href="%s" target="_blank">%s</a></div>',
                $employee['linkedin'],
                $label_linkedin
            );
        }

		/**
		 * Setup template
		 */
		$output = sprintf(
			'<div class="c-employee">
                <div class="c-employee__image-container">%s</div>
                <div class="c-employee__content">
                    <h3 class="c-employee__title">%s</h3>
                    %s
                    %s
                    %s
                    %s
                </div>
            </div>',
			$image,
			$title,
			$position,
			$email,
			$phone,
			$linkedin,
		);

        if ($settings['link_single'] == 'popup') {
            $output.= '<div class="YSPBusinessPopup c-employee-single-popup" data-popup='.$post_id.'>';
            ob_start();
            YSP_Business_Templates::render_single_template_content($post_id);
            $output.= ob_get_contents();
            ob_end_clean();
            $output.= '</div>';
        }

		return $output;
	}

	private function get_post_type_data( $post_id = null, $size = 'thumbnail', $image_class = '' ) {
        
        $img_class = $image_class ? 'aligncenter '. $image_class : 'aligncenter';
        
		$image = has_post_thumbnail( $post_id ) ? get_the_post_thumbnail( $post_id, $size, array( 'class' => $img_class ) ) : false;

        $position = get_post_meta( $post_id, '_employee_position', true );
        $email    = get_post_meta( $post_id, '_employee_email_address', true );
        $phone    = get_post_meta( $post_id, '_employee_phone_number', true );
        $linkedin = get_post_meta( $post_id, '_employee_linkedin', true );

		$output = array(
			'name'        => get_the_title( $post_id ),
			'image'       => $image,
			'position'    => $position,
			'email'       => $email,
			'phone'       => $phone,
			'linkedin'    => $linkedin,
		);

		return $output;
	}

}
