<?php
/***************************************
  Template - Office
****************************************/

class Business_Office_Template {

	private $settings = array(
		'post_id'          => null,
		'img_size'         => 'thumbnail',
		'link_single'      => false,
		'hide_address'     => false,
		'label_address'    => false,
		'hide_email'       => false,
		'label_email'      => false,
		'hide_phone'       => false,
		'label_phone'      => false,
		'hide_linkedin'    => false,
		'label_linkedin'   => false,
	);

	public function setArgs( $args ) {

		if ( ! empty( $args ) ) {
			foreach ( $args as $key => $value ) {
				$this->settings[ $key ] = $value;
			}
		}

	}

	public function render() {

		if ( ! isset( $this->settings['post_id'] ) ) {
			return '';
		}

		/**
		 * Setup initial options
		 */
		$post_id  = $this->settings['post_id'];
		$settings = $this->settings;

        // Declare Variables
        $label_address = $label_email = $label_phone = $label_linkedin = '';
        $address = $email = $phone = $linkedin = '';

        $label_address = YSP_Business_Helpers::get_label(
            $settings['hide_address'],
            $settings['label_address'],
            sprintf( '<span class="c-office__label">%s</span>', __( 'Address:', 'ysp-business' ) ),
        );

        $label_email = YSP_Business_Helpers::get_label(
            $settings['hide_email'],
            $settings['label_email'],
            sprintf( '<span class="c-office__label">%s</span>', __( 'Email:', 'ysp-business' ) ),
        );

        $label_phone = YSP_Business_Helpers::get_label(
            $settings['hide_phone'],
            $settings['label_phone'],
            sprintf( '<span class="c-office__label">%s</span>', __( 'Phone:', 'ysp-business' ) ),
        );

        $label_linkedin = YSP_Business_Helpers::get_label(
            $settings['hide_linkedin'],
            $settings['label_linkedin'],
            YSP_Business_Helpers::get_icon('linkedin'),
        );

		/**
		 * Setup office data
		 */
		$office = $this->get_post_type_data( $post_id, $settings['img_size'], 'c-office__image' );

		/**
		 * Setup template elements content
		 */
		$title = get_the_title( $post_id );

		$link_start = $settings['link_single'] ? '<a href="' . get_the_permalink( $post_id ) . '">' : '';
		$link_end   = $settings['link_single'] ? '</a>' : '';

		$image = $office['image'] ? $link_start . $office['image'] . $link_end : '';

		if ( $office['address'] ) {
		    $address = sprintf(
                '<div class="c-office__address">%s%s</div>',
                $label_address . ' ',
                $office['address']
            );
        }

		if ( $office['email'] ) {
		    $email = sprintf(
                '<div class="c-office__email">%s<a class="c-office__link" href="mailto:%s">%s</a></div>',
                $label_email . ' ',
                $office['email'],
                $office['email'],
            );
        }

		if ( $office['phone'] ) {
		    $phone = sprintf(
                '<div class="c-office__phone">%s<a class="c-office__link" href="tel:%s">%s</a></div>',
                $label_phone . ' ',
                $office['phone'],
                $office['phone'],
            );
        }

		if ( $office['linkedin'] ) {
            $linkedin = sprintf(
                '<div class="c-office__icon c-office__linkedin"><a href="%s" target="_blank">%s</a></div>',
                $office['linkedin'],
                $label_linkedin
            );
        }

		/**
		 * Setup template
		 */
		$output = sprintf(
			'<div class="c-office">
                <div class="c-office__image-container">%s</div>
                <div class="c-office__content">
                    <h3 class="c-office__title">%s</h3>
                    %s
                    %s
                    %s
                    %s
                </div>
            </div>',
			$image,
			$title,
			$address,
			$email,
			$phone,
			$linkedin,
		);

		return $output;
	}

	private function get_post_type_data( $post_id = null, $size = 'thumbnail', $image_class = '' ) {

		$img_class = $image_class ? 'aligncenter ' . $image_class : 'aligncenter';

		$image = has_post_thumbnail( $post_id ) ? get_the_post_thumbnail( $post_id, $size, array( 'class' => $img_class ) ) : false;

		$address = get_post_meta( $post_id, '_office_address', true );
		$email    = get_post_meta( $post_id, '_office_email_address', true );
		$phone    = get_post_meta( $post_id, '_office_phone_number', true );
        $linkedin = get_post_meta( $post_id, '_office_linkedin', true );

		$output = array(
			'name'        => get_the_title( $post_id ),
			'address'    => $address,
			'email'       => $email,
			'phone'       => $phone,
			'image'       => $image,
			'linkedin'    => $linkedin,
		);

		return $output;
	}

}
