<?php
/**
 * VC Integration - Employee Single
 *
 * @since 1.0
 */

add_action( 'vc_before_init', 'ysp_business_employee_single_integrateWithVC' );

function ysp_business_employee_single_integrateWithVC() {
	$params = array();

	$params[] = array(
		'type'        => 'dropdown',
		'heading'     => __( 'Employee', YSP_BUSINESS_TEXT_DOMAIN ),
		'param_name'  => 'employee_id',
		'admin_label' => true,
		'value'       => YSP_Business_Helpers::generate_post_list( 'employee' ),
		'description' => __( 'Select a single employee', YSP_BUSINESS_TEXT_DOMAIN ),
	);

	$params[] = array(
		'type'        => 'dropdown',
		'heading'     => __( 'Featured image size', YSP_BUSINESS_TEXT_DOMAIN ),
		'param_name'  => 'img_size',
		'admin_label' => true,
		'value'       => YSP_Business_Helpers::get_image_sizes(),
		'std'         => 'full',
		'description' => __( 'Select appropriate image size for the current column setup (default: full)', YSP_BUSINESS_TEXT_DOMAIN ),
	);

	$params[] = array(
		'type'        => 'dropdown',
		'heading'     => __( 'On click', 'ysp-business' ),
		'admin_label' => true,
		'param_name'  => 'link_single',
		'value'       => array(
            __( 'Not clickable', 'ysp-business' ) => 'false',
            __( 'Link to Single', 'ysp-business' ) => 'true',
            __( 'Open as Popup', 'ysp-business' ) => 'popup'
        ),
		'description' => __( 'By default items doesn\'t link to the single page', 'ysp-business' ),
	);

	$params[] = array(
		'type'        => 'dropdown',
		'heading'     => __( 'Position', YSP_BUSINESS_TEXT_DOMAIN ),
		'param_name'  => 'hide_position',
		'admin_label' => true,
		'value'       => array(
            __( 'Default', 'ysp-business' ) => '',
            __( 'Hide', 'ysp-business' ) => 'true',
            __( 'Custom', 'ysp-business' ) => 'custom',
        ),
        'std'         => 'true',
		'group'       => __( 'Labels', YSP_BUSINESS_TEXT_DOMAIN ),
	);

	$params[] = array(
		'type'        => 'textfield',
		'heading'     => '',
		'param_name'  => 'label_position',
		'value'       => '',
		'group'       => __( 'Labels', YSP_BUSINESS_TEXT_DOMAIN ),
		'description' => __( 'Add a custom position label', YSP_BUSINESS_TEXT_DOMAIN ),
        'dependency'  => array(
            'element' => 'hide_position',
            'value' => 'custom',
        ),
	);

	$params[] = array(
		'type'        => 'dropdown',
		'heading'     => __( 'Email address', YSP_BUSINESS_TEXT_DOMAIN ),
		'param_name'  => 'hide_email',
		'admin_label' => true,
		'value'       => array(
            __( 'Default', 'ysp-business' ) => '',
            __( 'Hide', 'ysp-business' ) => 'true',
            __( 'Custom', 'ysp-business' ) => 'custom',
        ),
        'std'         => '',
		'group'       => __( 'Labels', YSP_BUSINESS_TEXT_DOMAIN ),
	);

	$params[] = array(
		'type'        => 'textfield',
		'heading'     => '',
		'param_name'  => 'label_email',
		'value'       => '',
		'group'       => __( 'Labels', YSP_BUSINESS_TEXT_DOMAIN ),
		'description' => __( 'Add a custom email address label', YSP_BUSINESS_TEXT_DOMAIN ),
        'dependency'  => array(
            'element' => 'hide_email',
            'value' => 'custom',
        ),
	);

	$params[] = array(
		'type'        => 'dropdown',
		'heading'     => __( 'Phone number', YSP_BUSINESS_TEXT_DOMAIN ),
		'param_name'  => 'hide_phone',
		'admin_label' => true,
		'value'       => array(
            __( 'Default', 'ysp-business' ) => '',
            __( 'Hide', 'ysp-business' ) => 'true',
            __( 'Custom', 'ysp-business' ) => 'custom',
        ),
        'std'         => '',
		'group'       => __( 'Labels', YSP_BUSINESS_TEXT_DOMAIN ),
	);

	$params[] = array(
		'type'        => 'textfield',
		'heading'     => '',
		'param_name'  => 'label_phone',
		'value'       => '',
		'group'       => __( 'Labels', YSP_BUSINESS_TEXT_DOMAIN ),
		'description' => __( 'Add a custom phone number label', YSP_BUSINESS_TEXT_DOMAIN ),
        'dependency'  => array(
            'element' => 'hide_phone',
            'value' => 'custom',
        ),
	);

	$params[] = array(
		'type'        => 'dropdown',
		'heading'     => __( 'LinkedIn', YSP_BUSINESS_TEXT_DOMAIN ),
		'param_name'  => 'hide_linkedin',
		'admin_label' => true,
		'value'       => array(
            __( 'Default', 'ysp-business' ) => '',
            __( 'Hide', 'ysp-business' ) => 'true',
            __( 'Custom', 'ysp-business' ) => 'custom',
        ),
        'std'         => '',
		'group'       => __( 'Labels', YSP_BUSINESS_TEXT_DOMAIN ),
	);

	$params[] = array(
		'type'        => 'textfield',
		'heading'     => '',
		'param_name'  => 'label_linkedin',
		'value'       => '',
		'group'       => __( 'Labels', YSP_BUSINESS_TEXT_DOMAIN ),
		'description' => __( 'Add a custom LinkedIn label', YSP_BUSINESS_TEXT_DOMAIN ),
        'dependency'  => array(
            'element' => 'hide_linkedin',
            'value' => 'custom',
        ),
	);

	$params[] = array(
		'type'        => 'textfield',
		'heading'     => __( 'Custom CSS class', YSP_BUSINESS_TEXT_DOMAIN ),
		'param_name'  => 'class',
		'admin_label' => true,
		'value'       => '',
		'group'       => __( 'Advanced', YSP_BUSINESS_TEXT_DOMAIN ),
		'description' => __( 'Custom css class', YSP_BUSINESS_TEXT_DOMAIN ),
	);

	vc_map(
		array(
			'name'        => __( 'Employee Single', YSP_BUSINESS_TEXT_DOMAIN ),
			'base'        => 'ysp_business_employee',
			'class'       => '',
			'category'    => __( 'Business', YSP_BUSINESS_TEXT_DOMAIN ),
			'description' => __( 'A single employee', YSP_BUSINESS_TEXT_DOMAIN ),
			'params'      => $params,
			'icon'        => YSP_BUSINESS_VC_SYMBOL,
		)
	);
}