<?php
/**
 * VC Integration - Office Single
 *
 * @since 1.0
 */

add_action( 'vc_before_init', 'ysp_business_office_single_integrateWithVC' );

function ysp_business_office_single_integrateWithVC() {
	$params = array();

	$params[] = array(
		'type'        => 'dropdown',
		'heading'     => __( 'Office', 'ysp-business' ),
		'param_name'  => 'office_id',
		'admin_label' => true,
		'value'       => YSP_Business_Helpers::generate_post_list( 'office' ),
		'description' => __( 'Select a single office', 'ysp-business' ),
	);

	$params[] = array(
		'type'        => 'dropdown',
		'heading'     => __( 'Featured image size', 'ysp-business' ),
		'param_name'  => 'img_size',
		'admin_label' => true,
		'value'       => YSP_Business_Helpers::get_image_sizes(),
		'std'         => 'full',
		'description' => __( 'Select appropriate image size for the current column setup (default: full)', 'ysp-business' ),
	);

	$params[] = array(
		'type'        => 'checkbox',
		'heading'     => __( 'Enable single page link', 'ysp-business' ),
		'admin_label' => true,
		'param_name'  => 'link_single',
		'value'       => array( __( 'Yes', 'ysp-business' ) => 'true' ),
		'description' => __( 'By default items doesn\'t link to the single page', 'ysp-business' ),
	);

	$params[] = array(
		'type'        => 'dropdown',
		'heading'     => __( 'Address', YSP_BUSINESS_TEXT_DOMAIN ),
		'param_name'  => 'hide_address',
		'admin_label' => true,
		'value'       => array(
            __( 'Default', 'ysp-business' ) => '',
            __( 'Hide', 'ysp-business' ) => 'true',
            __( 'Custom', 'ysp-business' ) => 'custom',
        ),
        'std'         => 'true',
		'group'       => __( 'Labels', YSP_BUSINESS_TEXT_DOMAIN ),
	);

	$params[] = array(
		'type'        => 'textfield',
		'heading'     => '',
		'param_name'  => 'label_address',
		'value'       => '',
		'group'       => __( 'Labels', YSP_BUSINESS_TEXT_DOMAIN ),
		'description' => __( 'Add a custom address label', YSP_BUSINESS_TEXT_DOMAIN ),
        'dependency'  => array(
            'element' => 'hide_address',
            'value' => 'custom',
        ),
	);

	$params[] = array(
		'type'        => 'dropdown',
		'heading'     => __( 'Email address', YSP_BUSINESS_TEXT_DOMAIN ),
		'param_name'  => 'hide_email',
		'admin_label' => true,
		'value'       => array(
            __( 'Default', 'ysp-business' ) => '',
            __( 'Hide', 'ysp-business' ) => 'true',
            __( 'Custom', 'ysp-business' ) => 'custom',
        ),
        'std'         => '',
		'group'       => __( 'Labels', YSP_BUSINESS_TEXT_DOMAIN ),
	);

	$params[] = array(
		'type'        => 'textfield',
		'heading'     => '',
		'param_name'  => 'label_email',
		'value'       => '',
		'group'       => __( 'Labels', YSP_BUSINESS_TEXT_DOMAIN ),
		'description' => __( 'Add a custom email address label', YSP_BUSINESS_TEXT_DOMAIN ),
        'dependency'  => array(
            'element' => 'hide_email',
            'value' => 'custom',
        ),
	);

	$params[] = array(
		'type'        => 'dropdown',
		'heading'     => __( 'Phone number', YSP_BUSINESS_TEXT_DOMAIN ),
		'param_name'  => 'hide_phone',
		'admin_label' => true,
		'value'       => array(
            __( 'Default', 'ysp-business' ) => '',
            __( 'Hide', 'ysp-business' ) => 'true',
            __( 'Custom', 'ysp-business' ) => 'custom',
        ),
        'std'         => '',
		'group'       => __( 'Labels', YSP_BUSINESS_TEXT_DOMAIN ),
	);

	$params[] = array(
		'type'        => 'textfield',
		'heading'     => '',
		'param_name'  => 'label_phone',
		'value'       => '',
		'group'       => __( 'Labels', YSP_BUSINESS_TEXT_DOMAIN ),
		'description' => __( 'Add a custom phone number label', YSP_BUSINESS_TEXT_DOMAIN ),
        'dependency'  => array(
            'element' => 'hide_phone',
            'value' => 'custom',
        ),
	);

	$params[] = array(
		'type'        => 'dropdown',
		'heading'     => __( 'LinkedIn', YSP_BUSINESS_TEXT_DOMAIN ),
		'param_name'  => 'hide_linkedin',
		'admin_label' => true,
		'value'       => array(
            __( 'Default', 'ysp-business' ) => '',
            __( 'Hide', 'ysp-business' ) => 'true',
            __( 'Custom', 'ysp-business' ) => 'custom',
        ),
        'std'         => '',
		'group'       => __( 'Labels', YSP_BUSINESS_TEXT_DOMAIN ),
	);

	$params[] = array(
		'type'        => 'textfield',
		'heading'     => '',
		'param_name'  => 'label_linkedin',
		'value'       => '',
		'group'       => __( 'Labels', YSP_BUSINESS_TEXT_DOMAIN ),
		'description' => __( 'Add a custom LinkedIn label', YSP_BUSINESS_TEXT_DOMAIN ),
        'dependency'  => array(
            'element' => 'hide_linkedin',
            'value' => 'custom',
        ),
	);

	$params[] = array(
		'type'        => 'textfield',
		'class'       => '',
		'heading'     => __( 'Custom CSS class', 'ysp-business' ),
		'param_name'  => 'class',
		'admin_label' => true,
		'value'       => '',
		'group'       => __( 'Advanced', 'ysp-business' ),
		'description' => __( 'Custom css class', 'ysp-business' ),
	);

	vc_map(
		array(
			'name'        => __( 'Office Single', 'ysp-business' ),
			'base'        => 'ysp_business_office',
			'class'       => '',
			'category'    => __( 'Business', 'ysp-business' ),
			'description' => __( 'A single office', 'ysp-business' ),
			'params'      => $params,
			'icon'        => YSP_BUSINESS_VC_SYMBOL,
		)
	);
}