<?php
/**
 * Employee Shortcodes
 */

class YSP_Business_Employee_Shortcodes {

	public function __construct() {
		add_shortcode( 'yspb_employee_data', array( $this, 'yspb_employee_data_shortcode' ) );
		add_shortcode( 'yspb_employee_image', array( $this, 'yspb_employee_image_shortcode' ) );
		add_shortcode( 'yspb_employee_cats', array( $this, 'yspb_employee_cats_shortcode' ) );
		add_shortcode( 'yspb_employee_office', array( $this, 'yspb_employee_office_shortcode' ) );
		add_shortcode( 'yspb_employee_content', array( $this, 'yspb_employee_content_shortcode' ) );
	}

	public function yspb_employee_data_shortcode( $atts ) {
		$options = shortcode_atts(
			array(
				'id' => get_the_id(),
				'field' => '',
				'html_tag' => '',
				'class' => '',
			),
			$atts,
			'yspb_employee_data'
		);

        $customCss = $options['class'] ? ' '. $options['class'] : '';
        $html_tag  = $options['html_tag'] ? $options['html_tag'] : 'div';

        $output = '';
        ob_start();

		if ( !empty( $options['id'] ) && !empty( $options['field'] ) ) {
            $output .= get_post_meta( $options['id'], $options['field'], true );
        }

        $output .= ob_get_clean();
		return '<'. $html_tag .' class="c-employee-data'. $customCss .'">'. $output .'</'. $html_tag .'>';
	}

	public function yspb_employee_image_shortcode( $atts ) {
		$options = shortcode_atts(
			array(
				'id' => get_the_id(),
				'size' => 'full',
				'html_tag' => '',
				'class' => '',
			),
			$atts,
			'yspb_employee_image'
		);

        $customCss = $options['class'] ? ' '. $options['class'] : '';
        $html_tag  = $options['html_tag'] ? $options['html_tag'] : 'div';

        $output = '';
        ob_start();

		if ( !empty( $options['id'] ) ) {
            $output .= get_the_post_thumbnail( $options['id'], $options['size'], array( 'class' => 'c-employee-image__tag' ) );
        }

        $output .= ob_get_clean();
		return '<'. $html_tag .' class="c-employee-image'. $customCss .'">'. $output .'</'. $html_tag .'>';
	}

	public function yspb_employee_cats_shortcode( $atts ) {
		$options = shortcode_atts(
			array(
				'id' => get_the_id(),
				'separator' => ' | ',
				'html_tag' => '',
				'class' => '',
			),
			$atts,
			'yspb_employee_cats'
		);

        $customCss = $options['class'] ? ' '. $options['class'] : '';
        $html_tag  = $options['html_tag'] ? $options['html_tag'] : 'div';

        $output = '';
        ob_start();

		if ( !empty( $options['id'] ) ) {
            $cats = get_the_terms( $options['id'], 'employee_category' );
            $i = 0;
            $numCats = count( $cats );
            foreach ( $cats as $cat ) {
                echo $cat->name;
                if ( ++$i !== $numCats ) {
                    echo $options['separator'];
                }
            }
        }

        $output .= ob_get_clean();
		return '<'. $html_tag .' class="c-employee-category'. $customCss .'">'. $output .'</'. $html_tag .'>';
	}

	public function yspb_employee_office_shortcode( $atts ) {
		$options = shortcode_atts(
			array(
				'id' => get_the_id(),
				'separator' => ' | ',
				'html_tag' => '',
				'class' => '',
			),
			$atts,
			'yspb_employee_office'
		);

        $customCss = $options['class'] ? ' '. $options['class'] : '';
        $html_tag  = $options['html_tag'] ? $options['html_tag'] : 'div';

        $output = '';
        ob_start();

		if ( !empty( $options['id'] ) ) {
            $offices = get_post_meta( $options['id'], '_employee_office', true );
            $i = 0;
            $numOffices = count( $offices );
            foreach ( $offices as $office ) {
                if ( !empty( get_post( $office ) ) ) {
                    echo get_post( $office )->post_title;
                    if ( ++$i !== $numOffices ) {
                        echo $options['separator'];
                    }
                }
            }
        }

        $output .= ob_get_clean();
		return '<'. $html_tag .' class="c-employee-office'. $customCss .'">'. $output .'</'. $html_tag .'>';
	}

	public function yspb_employee_content_shortcode( $atts, $content = null ) {
		$options = shortcode_atts(
			array(
				'id' => get_the_id(),
				'html_tag' => '',
				'class' => '',
			),
			$atts,
			'yspb_office_cats'
		);

        $customCss = $options['class'] ? ' '. $options['class'] : '';
        $html_tag  = $options['html_tag'] ? $options['html_tag'] : 'div';

        $output = '';
        ob_start();

		if ( !empty( $options['id'] ) ) {
            $getPost = get_post( $options['id'] ); 
            $content = apply_filters( 'the_content', $getPost->post_content );
            $output = (!empty($content)) ? $content : '';
        }

        $output .= ob_get_clean();
		return '<'. $html_tag .' class="c-employee-content'. $customCss .'">'. $output .'</'. $html_tag .'>';
	}

}
new YSP_Business_Employee_Shortcodes();