<?php
/**
 * Office Shortcodes
 */

class YSP_Business_Office_Shortcodes {

	public function __construct() {
		add_shortcode( 'yspb_office_data', array( $this, 'yspb_office_data_shortcode' ) );
		add_shortcode( 'yspb_office_image', array( $this, 'yspb_office_image_shortcode' ) );
		add_shortcode( 'yspb_office_cats', array( $this, 'yspb_office_cats_shortcode' ) );
		add_shortcode( 'yspb_office_content', array( $this, 'yspb_office_content_shortcode' ) );
	}

	public function yspb_office_data_shortcode( $atts ) {
		$options = shortcode_atts(
			array(
				'id' => get_the_id(),
				'field' => '',
				'html_tag' => '',
				'class' => '',
			),
			$atts,
			'yspb_office_data'
		);

        $customCss = $options['class'] ? ' '. $options['class'] : '';
        $html_tag  = $options['html_tag'] ? $options['html_tag'] : 'div';

        $output = '';
        ob_start();

		if ( !empty( $options['id'] ) && !empty( $options['field'] ) ) {
            $output .= get_post_meta( $options['id'], $options['field'], true );
        }

        $output .= ob_get_clean();
		return '<'. $html_tag .' class="c-office-data'. $customCss .'">'. $output .'</'. $html_tag .'>';
	}

	public function yspb_office_image_shortcode( $atts ) {
		$options = shortcode_atts(
			array(
				'id' => get_the_id(),
				'size' => 'full',
				'html_tag' => '',
				'class' => '',
			),
			$atts,
			'yspb_office_image'
		);

        $customCss = $options['class'] ? ' '. $options['class'] : '';
        $html_tag  = $options['html_tag'] ? $options['html_tag'] : 'div';

        $output = '';
        ob_start();

		if ( !empty( $options['id'] ) ) {
            $output .= get_the_post_thumbnail( $options['id'], $options['size'], array( 'class' => 'c-office-image__tag' ) );
        }

        $output .= ob_get_clean();
		return '<'. $html_tag .' class="c-office-image'. $customCss .'">'. $output .'</'. $html_tag .'>';
	}

	public function yspb_office_cats_shortcode( $atts ) {
		$options = shortcode_atts(
			array(
				'id' => get_the_id(),
				'separator' => ' | ',
				'html_tag' => '',
				'class' => '',
			),
			$atts,
			'yspb_office_cats'
		);

        $customCss = $options['class'] ? ' '. $options['class'] : '';
        $html_tag  = $options['html_tag'] ? $options['html_tag'] : 'div';

        $output = '';
        ob_start();

		if ( !empty( $options['id'] ) ) {
            $cats = get_the_terms( $options['id'], 'office_category' );
            $i = 0;
            $numCats = count( $cats );
            foreach ( $cats as $cat ) {
                echo $cat->name;
                if ( ++$i !== $numCats ) {
                    echo ' | ';
                }
            }
        }

        $output .= ob_get_clean();
		return '<'. $html_tag .' class="c-office-category'. $customCss .'">'. $output .'</'. $html_tag .'>';
	}

	public function yspb_office_content_shortcode( $atts, $content = null ) {
		$options = shortcode_atts(
			array(
				'id' => get_the_id(),
				'html_tag' => '',
				'class' => '',
			),
			$atts,
			'yspb_office_cats'
		);

        $customCss = $options['class'] ? ' '. $options['class'] : '';
        $html_tag  = $options['html_tag'] ? $options['html_tag'] : 'div';

        $output = '';
        ob_start();

		if ( !empty( $options['id'] ) ) {
            $getPost = get_post( $options['id'] ); 
            $content = apply_filters( 'the_content', $getPost->post_content );
            $output = (!empty($content)) ? $content : '';
        }

        $output .= ob_get_clean();
		return '<'. $html_tag .' class="c-office-content'. $customCss .'">'. $output .'</'. $html_tag .'>';
	}

}
new YSP_Business_Office_Shortcodes();