<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://your-style.nl/
 * @since      1.0.0
 *
 * @package    Ysp_Business
 * @subpackage Ysp_Business/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Ysp_Business
 * @subpackage Ysp_Business/public
 * @author     Yourstyle <info@your-style.nl>
 */
class Ysp_Business_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string $plugin_name       The name of the plugin.
	 * @param      string $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version     = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Ysp_Business_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Ysp_Business_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

        /* Swiper CSS */
		if ( ! wp_script_is( 'swiper_style_core', 'registered' ) ) {
            wp_register_style( 'swiper_style_core', 'https://cdnjs.cloudflare.com/ajax/libs/Swiper/5.4.1/css/swiper.min.css', array(), '5.4.1', 'all' );
        }

		wp_register_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'assets/dist/css/ysp-business-public.min.css', array(), $this->version, 'all' );

        // Enqueue Style on Employee & Office Singles when no enqueued.
        if ( is_singular( 'employee' ) || is_singular( 'office' )  ) {
            if ( ! wp_style_is( $this->plugin_name, 'enqueued' ) ) {
                wp_enqueue_style( $this->plugin_name );
            }
        }
	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Ysp_Business_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Ysp_Business_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

         /* Swiper JS */
		if ( ! wp_script_is( 'slider_core', 'registered' ) ) {
			wp_register_script( 'slider_core', 'https://cdnjs.cloudflare.com/ajax/libs/Swiper/5.4.1/js/swiper.min.js', array( 'jquery' ), '5.4.1', true );
		}

		wp_register_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'assets/dist/js/ysp-business-public.min.js', array( 'jquery' ), $this->version, false );
		wp_register_script( $this->plugin_name . '-slider', plugin_dir_url( __FILE__ ) . 'assets/dist/js/ysp-business-slider.min.js', array( 'slider_core' ), $this->version, true );
	}

}
